@@ -1,8 +1,17 @@
 from datetime import datetime
+from json import dumps
+from typing import List
 from typing import Optional
 
 from pydantic import BaseModel, validator, NonNegativeFloat
-from typing import List
+
+
+def custom_dumps(args, *, default):
+    print(args)
+    for k, v in args.items():
+        if isinstance(v, datetime):
+            args[k] = v.strftime('%Y-%m-%d')
+    return dumps(args, default=default)
 
 
 class OperationItems(BaseModel):
@@ -14,9 +23,15 @@ class OperationItems(BaseModel):
     firstAdditionalOperationAttributeId: Optional[int]
     value: NonNegativeFloat
 
-    @validator('calculationDate')
+    class Config:
+        json_dumps = custom_dumps
+
+    @validator('calculationDate', pre=True)
     def remainder_date(cls, v):
-        return v.strftime('%Y-%m-%d')
+        if v is not None and isinstance(v, str):
+            return datetime.strptime(v, '%Y-%m-%d')
+        else:
+            return v
 
     @validator('projectId', 'operationCategoryId')
     def check_for_zero_ids(cls, v):
@@ -36,50 +51,49 @@ class IncomeOutcomeOperation(BaseModel):
     comment: Optional[str]
     value: Optional[NonNegativeFloat]
     isCommitted: Optional[bool]
-    items: List[OperationItems]
+    items: Optional[List[OperationItems]]
     externalId: Optional[str]
     distributeCalculationDate: Optional[datetime]
     distributeCalculationType: Optional[str]
 
-    @validator('operationDate', 'calculationDate', 'distributeCalculationDate')
+    class Config:
+        json_dumps = custom_dumps
+
+    @validator('calculationDate', 'distributeCalculationDate', 'operationDate', pre=True)
     def remainder_date(cls, v):
-        return v.strftime('%Y-%m-%d')
+        if v is not None and isinstance(v, str):
+            return datetime.strptime(v, '%Y-%m-%d')
+        else:
+            return v
 
 
 class MoveOperation(BaseModel):
     """
-    debitingDate: string (date)     Дата списания
-    admissionDate: string (date)     Дата зачисления
-    debitingAccountId: integer (int32)     Счет списания
-    admissionAccountId: integer (int32)     Счет зачисления
-    debitingValue: number (double) x ≥ 0     Сумма списания
-    admissionValue: number (double) x ≥ 0     Сумма зачисления
-    comment: string     Комментарий
-    valueByProjects: object     Сумма по проектам
-    isCommitted: boolean     Признак того, что операция проведена
-    importLogId: integer (int32)     Идентификатор лога импорта
-    debitingItems: OperationPartRequest     Части операции списания
-    admissionItems: OperationPartRequest     Части операции зачисления
-    debitingExternalId: string   Внешний идентификатор для списания
-    admissionExternalId: string   Внешний идентификатор для зачисления
+    valueByProjects: object     Сумма по проектам  not implemented!
     """
-    debitingDate: datetime
-    admissionDate: datetime
-    debitingAccountId: int
-    admissionAccountId: int
-    debitingValue: Optional[NonNegativeFloat]
-    admissionValue: Optional[NonNegativeFloat]
-    comment: Optional[str]
-    isCommitted: Optional[bool]
-    importLogId: Optional[int]
-    debitingItems: Optional[List[OperationItems]]
-    admissionItems: Optional[List[OperationItems]]
-    debitingExternalId: Optional[str]
-    admissionExternalId: Optional[str]
+    debitingDate: datetime  # Дата списания
+    admissionDate: datetime  # Дата зачисления
+    debitingAccountId: int  # Счет списания
+    admissionAccountId: int  # Счет зачисления
+    debitingValue: Optional[NonNegativeFloat]  # Сумма списания
+    admissionValue: Optional[NonNegativeFloat]  # Сумма зачисления
+    comment: Optional[str]  # Комментарий
+    isCommitted: Optional[bool]  # Признак того, что операция проведена
+    importLogId: Optional[int]  # Идентификатор лога импорта
+    debitingItems: Optional[List[OperationItems]]  # Части операции списания
+    admissionItems: Optional[List[OperationItems]]  # Части операции зачисления
+    debitingExternalId: Optional[str]  # Внешний идентификатор для списания
+    admissionExternalId: Optional[str]  # Внешний идентификатор для зачисления
 
-    @validator('debitingDate', 'admissionDate')
+    class Config:
+        json_dumps = custom_dumps
+
+    @validator('debitingDate', 'admissionDate', pre=True)
     def remainder_date(cls, v):
-        return v.strftime('%Y-%m-%d')
+        if v is not None and isinstance(v, str):
+            return datetime.strptime(v, '%Y-%m-%d')
+        else:
+            return v
 
     def set_to_committed(self):
         self.isCommitted = True
